@@ -4,6 +4,7 @@
 
 in terminal in tests folder.
 """
-from . import test_it
+from . import test_cicd
+from . import test_helpers
 
-__all__ = ["test_it"]
+__all__ = ["test_cicd", "test_helpers"]
